{% load i18n %}

<p>
    {% block introduction %}
    {% blocktrans %}
        Hello {{ username }},
    {% endblocktrans %}
    {% endblock %}
</p>
<p>
    {% block status_information %}
    {% blocktrans %}
        Your proctored exam "{{ exam_name }}" in
        <a href="{{ course_url }}">{{ course_name }}</a> was reviewed and the
        course team has identified one or more violations of the proctored exam rules. Examples
        of issues that may result in a rules violation include browsing
        the internet, blurry or missing photo identification, using a phone,
        or getting help from another person. As a result of the identified issue(s),
        you did not successfully meet the proctored exam requirements.
    {% endblocktrans %}
    {% endblock %}
</p>
<p>
    {% block contact_information %}
    {% blocktrans %}
        To appeal your proctored exam results, please reach out with any relevant information
        about your exam at 
        <a href="{{contact_url}}">
            {{ contact_url_text }}
        </a>.
    {% endblocktrans %}
    {% endblock %}
</p>
