# Generated by Django 2.2.17 on 2021-05-06 13:49

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('edx_proctoring', '0013_proctoredexamsoftwaresecurereview_is_active_attempt'),
    ]

    operations = [
        migrations.AddField(
            model_name='proctoredexamstudentattempt',
            name='is_resumable',
            field=models.BooleanField(default=False, verbose_name='Is Resumable'),
        ),
        migrations.AddField(
            model_name='proctoredexamstudentattempthistory',
            name='is_resumable',
            field=models.BooleanField(default=False),
        ),
    ]
